@@ -6,12 +6,18 @@
  * Daniel Veillard <daniel@veillard.com>
  */
 
+#define IN_LIBXML
 #include "libxml.h"
 
 #include <stdarg.h>
 #include <libxml/parser.h>
 #include <libxml/xmlerror.h>
 #include <libxml/xmlmemory.h>
+#include <libxml/globals.h>
+
+void xmlGenericErrorDefaultFunc	(void *ctx ATTRIBUTE_UNUSED,
+				 const char *msg,
+				 ...);
 
 #define XML_GET_VAR_STR(msg, str) {				\
     int       size;						\
@@ -57,7 +63,7 @@
  * 
  * Default handler for out of context error messages.
  */
-static void
+void
 xmlGenericErrorDefaultFunc(void *ctx ATTRIBUTE_UNUSED, const char *msg, ...) {
     va_list args;
 
@@ -69,9 +75,20 @@ xmlGenericErrorDefaultFunc(void *ctx ATTRIBUTE_UNUSED, const char *msg, ...) {
     va_end(args);
 }
 
-xmlGenericErrorFunc xmlGenericError = xmlGenericErrorDefaultFunc;
-void *xmlGenericErrorContext = NULL;
-
+/**
+ * initGenericErrorDefaultFunc:
+ * @handler:  the handler
+ * 
+ * Set or reset (if NULL) the default handler for generic errors
+ */
+void
+initGenericErrorDefaultFunc(xmlGenericErrorFunc * handler)
+{
+    if (handler == NULL)
+        xmlGenericError = xmlGenericErrorDefaultFunc;
+    else
+        (*handler) = xmlGenericErrorDefaultFunc;
+}
 
 /**
  * xmlSetGenericErrorFunc:
@@ -255,7 +272,7 @@ xmlParserError(void *ctx, const char *msg, ...)
 
     xmlGenericError(xmlGenericErrorContext, "error: ");
     XML_GET_VAR_STR(msg, str);
-    xmlGenericError(xmlGenericErrorContext, str);
+    xmlGenericError(xmlGenericErrorContext, "%s", str);
     if (str != NULL)
 	xmlFree(str);
 
@@ -298,7 +315,7 @@ xmlParserWarning(void *ctx, const char *msg, ...)
         
     xmlGenericError(xmlGenericErrorContext, "warning: ");
     XML_GET_VAR_STR(msg, str);
-    xmlGenericError(xmlGenericErrorContext, str);
+    xmlGenericError(xmlGenericErrorContext, "%s", str);
     if (str != NULL)
 	xmlFree(str);
 
@@ -333,22 +350,33 @@ xmlParserValidityError(void *ctx, const char *msg, ...)
     xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
     xmlParserInputPtr input = NULL;
     char * str;
+    int len = xmlStrlen((const xmlChar *) msg);
+    static int had_info = 0;
+    int need_context = 0;
 
-    if (ctxt != NULL) {
-	input = ctxt->input;
-	if ((input->filename == NULL) && (ctxt->inputNr > 1))
-	    input = ctxt->inputTab[ctxt->inputNr - 2];
-	    
-	xmlParserPrintFileInfo(input);
+    if ((len > 1) && (msg[len - 2] != ':')) {
+	if (ctxt != NULL) {
+	    input = ctxt->input;
+	    if ((input->filename == NULL) && (ctxt->inputNr > 1))
+		input = ctxt->inputTab[ctxt->inputNr - 2];
+		
+	    if (had_info == 0) {
+		xmlParserPrintFileInfo(input);
+	    }
+	}
+	xmlGenericError(xmlGenericErrorContext, "validity error: ");
+	need_context = 1;
+	had_info = 0;
+    } else {
+	had_info = 1;
     }
 
-    xmlGenericError(xmlGenericErrorContext, "validity error: ");
     XML_GET_VAR_STR(msg, str);
-    xmlGenericError(xmlGenericErrorContext, str);
+    xmlGenericError(xmlGenericErrorContext, "%s", str);
     if (str != NULL)
 	xmlFree(str);
 
-    if (ctxt != NULL) {
+    if ((ctxt != NULL) && (input != NULL)) {
 	xmlParserPrintFileContext(input);
     }
 }
@@ -368,8 +396,9 @@ xmlParserValidityWarning(void *ctx, const char *msg, ...)
     xmlParserCtxtPtr ctxt = (xmlParserCtxtPtr) ctx;
     xmlParserInputPtr input = NULL;
     char * str;
+    int len = xmlStrlen((const xmlChar *) msg);
 
-    if (ctxt != NULL) {
+    if ((ctxt != NULL) && (len != 0) && (msg[len - 1] != ':')) {
 	input = ctxt->input;
 	if ((input->filename == NULL) && (ctxt->inputNr > 1))
 	    input = ctxt->inputTab[ctxt->inputNr - 2];
@@ -379,7 +408,7 @@ xmlParserValidityWarning(void *ctx, const char *msg, ...)
         
     xmlGenericError(xmlGenericErrorContext, "validity warning: ");
     XML_GET_VAR_STR(msg, str);
-    xmlGenericError(xmlGenericErrorContext, str);
+    xmlGenericError(xmlGenericErrorContext, "%s", str);
     if (str != NULL)
 	xmlFree(str);
 
