@@ -76,6 +76,7 @@
 #include <libxml/parser.h> /* for xmlStr(n)casecmp() */
 #include <libxml/nanohttp.h>
 #include <libxml/globals.h>
+#include <libxml/uri.h>
 
 /**
  * A couple portability macros
@@ -371,6 +372,7 @@ xmlNanoHTTPScanProxy(const char *URL) {
 static xmlNanoHTTPCtxtPtr
 xmlNanoHTTPNewCtxt(const char *URL) {
     xmlNanoHTTPCtxtPtr ret;
+    xmlChar *escaped;
 
     ret = (xmlNanoHTTPCtxtPtr) xmlMalloc(sizeof(xmlNanoHTTPCtxt));
     if (ret == NULL) return(NULL);
@@ -381,7 +383,13 @@ xmlNanoHTTPNewCtxt(const char *URL) {
     ret->fd = -1;
     ret->ContentLength = -1;
 
-    xmlNanoHTTPScanURL(ret, URL);
+    escaped = xmlURIEscapeStr(BAD_CAST URL, BAD_CAST"@/:=?;#%&");
+    if (escaped != NULL) {
+	xmlNanoHTTPScanURL(ret, (const char *) escaped);
+	xmlFree(escaped);
+    } else {
+	xmlNanoHTTPScanURL(ret, URL);
+    }
 
     return(ret);
 }
@@ -1137,28 +1145,30 @@ retry:
 
     if (proxy) {
 	if (ctxt->port != 80) {
-	    p += sprintf( p, "%s http://%s:%d%s", method, ctxt->hostname,
+	    p += snprintf( p, blen - (p - bp), "%s http://%s:%d%s", 
+			method, ctxt->hostname,
 		 	ctxt->port, ctxt->path );
 	}
-	else
-	    p += sprintf( p, "%s http://%s%s", method,
+	else 
+	    p += snprintf( p, blen - (p - bp), "%s http://%s%s", method,
 	    		ctxt->hostname, ctxt->path);
     }
     else
-	p += sprintf( p, "%s %s", method, ctxt->path);
+	p += snprintf( p, blen - (p - bp), "%s %s", method, ctxt->path);
 
-    p += sprintf(p, " HTTP/1.0\r\nHost: %s\r\n", ctxt->hostname);
+    p += snprintf( p, blen - (p - bp), " HTTP/1.0\r\nHost: %s\r\n", 
+		    ctxt->hostname);
 
     if (contentType != NULL && *contentType) 
-	p += sprintf(p, "Content-Type: %s\r\n", *contentType);
+	p += snprintf(p, blen - (p - bp), "Content-Type: %s\r\n", *contentType);
 
     if (headers != NULL)
-	p += sprintf( p, "%s", headers );
+	p += snprintf( p, blen - (p - bp), "%s", headers );
 
     if (input != NULL)
-	sprintf(p, "Content-Length: %d\r\n\r\n", ilen );
+	snprintf(p, blen - (p - bp), "Content-Length: %d\r\n\r\n", ilen );
     else
-	strcpy(p, "\r\n");
+	snprintf(p, blen - (p - bp), "\r\n");
 
 #ifdef DEBUG_HTTP
     xmlGenericError(xmlGenericErrorContext,
@@ -1409,9 +1419,11 @@ xmlNanoHTTPAuthHeader(void *ctx) {
 }
 
 /**
- * xmlNanoHTTPContentLength
+ * xmlNanoHTTPContentLength:
  * @ctx:  the HTTP context
  *
+ * Provides the specified content length from the HTTP header.
+ *
  * Return the specified content length from the HTTP header.  Note that
  * a value of -1 indicates that the content length element was not included in
  * the response header.
@@ -1424,11 +1436,13 @@ xmlNanoHTTPContentLength( void * ctx ) {
 }
 
 /**
- * xmlNanoHTTPFetchContent
+ * xmlNanoHTTPFetchContent:
  * @ctx:  the HTTP context
  * @ptr:  pointer to set to the content buffer.
  * @len:  integer pointer to hold the length of the content
  *
+ * Check if all the content was read
+ *
  * Returns 0 if all the content was read and available, returns
  * -1 if received content length was less than specified or an error 
  * occurred.
