@@ -528,7 +528,7 @@ def buildStubs():
     wrapper = open("libxml2-py.c", "w")
     wrapper.write("/* Generated */\n\n")
     wrapper.write("#include <Python.h>\n")
-    wrapper.write("#include \"config.h\"\n")
+#    wrapper.write("#include \"config.h\"\n")
     wrapper.write("#include <libxml/xmlversion.h>\n")
     wrapper.write("#include <libxml/tree.h>\n")
     wrapper.write("#include \"libxml_wrap.h\"\n")
